PALM-meteo: palmmeteo.library.AssimCycle Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.library.AssimCycle Class Reference

## Public Member Functions
def | __init__ (self, cfgsect)

## Public Attributes
| cycle_int
| is_selected
| cycle_ref

## Detailed Description

    List of selected assimilation cycles based on configuration

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.library.AssimCycle.__init__ | ( |  | self,
|  |  | cfgsect
| ) |  |

## Member Data Documentation

## ◆ cycle_int

palmmeteo.library.AssimCycle.cycle_int

## ◆ cycle_ref

palmmeteo.library.AssimCycle.cycle_ref

## ◆ is_selected

palmmeteo.library.AssimCycle.is_selected

The documentation for this class was generated from the following file:

- palmmeteo/library.py